@@ -49,7 +49,7 @@ sub get_download_infos {
         my $key_len = 13;
         my $print_array = linefolded_print_info( $opt, $info, $video_id, $key_len );
         my $status_not_ok;
-        if ( defined $info->{$video_id}{status} && $info->{$video_id}{status} ne 'ok' ) { # $info->{$video_id}{youtube}
+        if ( defined $info->{$video_id}{status} && $info->{$video_id}{status} ne 'ok' ) {
             $status_not_ok = 1;
             unshift @$print_array, sprintf "%*.*s : %s  %s\n", $key_len, $key_len, 'video', $count, 'Status NOT OK!';
         }
@@ -126,15 +126,17 @@ sub get_download_infos {
             print for map { encode_stdout_lax( $_ ) } @$print_array;
             binmode STDOUT, ':encoding(console_out)';
             print "\n";
-            if ( $opt->{max_channels} && $info->{$video_id}{youtube} && $info->{$video_id}{uploader_id} ) {
-                my $channel    = $info->{$video_id}{uploader};
-                my $channel_id = $info->{$video_id}{uploader_id};
-                if ( none{ $channel_id eq ( split /,/, $_ )[1] } @{$opt->{channel_sticky}} ) {
-                    my $idx = first_index { $channel_id eq ( split /,/, $_ )[1] } @{$opt->{channel_history}};
-                    if ( $idx > -1 ) {
-                        splice @{$opt->{channel_history}}, $idx, 1;
+            if ( $opt->{max_channels} && $info->{$video_id}{uploader_id} ) {
+                if ( $info->{$video_id}{extractor_key} eq 'Youtube' ) {
+                    my $channel    = $info->{$video_id}{uploader};
+                    my $channel_id = $info->{$video_id}{uploader_id};
+                    if ( none{ $channel_id eq ( split /,/, $_ )[1] } @{$opt->{channel_sticky}} ) {
+                        my $idx = first_index { $channel_id eq ( split /,/, $_ )[1] } @{$opt->{channel_history}};
+                        if ( $idx > -1 ) {
+                            splice @{$opt->{channel_history}}, $idx, 1;
+                        }
+                        unshift @{$opt->{channel_history}}, sprintf "%s,%s", $channel, $channel_id;
                     }
-                    unshift @{$opt->{channel_history}}, sprintf "%s,%s", $channel, $channel_id;
                 }
             }
         }
@@ -183,7 +185,7 @@ sub _get_filename {
 sub _fmt_quality {
     my ( $opt, $info, $fmt, $video_id ) = @_;
     my $auto_quality = $opt->{auto_quality};
-    $auto_quality = 2 if $auto_quality == 3 && ! $info->{$video_id}{youtube};
+    $auto_quality = 2 if $auto_quality == 3 && $info->{$video_id}{extractor_key} ne 'Youtube';
     my $fmt_ok;
     if ( $auto_quality == 0 ) {
     }
@@ -247,7 +249,7 @@ sub _choose_fmt {
     my ( $opt, $info, $video_id ) = @_;
     my ( @choices, @format_ids );
     my @fmts;
-    if ( $info->{$video_id}{youtube} ) {
+    if ( $info->{$video_id}{extractor_key} eq 'Youtube' ) {
         for my $fmt ( sort { $a <=> $b } keys %{$info->{$video_id}{fmt_to_info}} ) {
             my ( $fmt, $desc ) = split '\s*-\s*', $info->{$video_id}{fmt_to_info}{$fmt}{format};
             $desc = '' if ! $desc;
